$wnd.rstudio.runAsyncCallback27("function O_j(){}\nfunction p0j(a){this.a=a}\nfunction H_j(a,b){D2j(a.c,b)}\nfunction A_j(a,b){var c,d;c=x3j(Y5j(a.d.a));if(c.a.length==0){X9j(a.b,false);b.gn()}d=Z2d($2d(new d3d(null,new V_d(c)),new O_j));if(e6c(d,0)>0){W5c().SC(1,'Local Jobs Still Running','The Jobs tab cannot be closed while there '+(e6c(d,1)>0?'are unfinished local jobs.':'is an unfinished local job.')+'\\n\\nWait until all local jobs have completed.').TC();return}X9j(a.b,false);b.gn()}\nfunction l0j(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=g6j(a.a.b.a);rQi(a.a,a.a.a)}switch(a.c){case 1:A_j(a.a.a,a.b[0]);break;case 2:B_j(a.a.a);break;case 3:a.a.a.J.zI();break;case 4:a.a.a.J.AI();break;case 5:C_j(a.a.a,a.b[0]);break;case 6:D_j(a.a.a,a.b[0]);break;case 7:E_j(a.a.a,a.b[0]);break;case 8:F_j(a.a.a,a.b[0]);break;case 9:G_j(a.a.a,a.b[0]);break;case 10:a.a.a.J.BI();break;case 11:a.a.a.J.CI();break;case 12:H_j(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nE6c(7126,1,{},O_j);_.Yt=function P_j(a){return a.type==1&&a.state==2};var Lcc=nQd(7126);E6c(321,1,gio);_.en=function o0j(){l0j((new p0j(this)).a)};E6c(6598,1,ISn,p0j);_.gn=function q0j(){l0j(this.a)};var Scc=nQd(6598);wJn(hm)(27);\n//# sourceURL=rstudio-27.js\n")
