[{"locale":"es"},{"key":"F","names":["F","F.","°F"],"mappings":{"default":{"default":"Fahrenheit"}}},{"key":"C","names":["C","°C"],"mappings":{"default":{"default":"centígrados"}}},{"key":"K","names":["K","°K"],"mappings":{"default":{"default":"Kelvin"}}}]
